Class: Google::Protobuf::Api

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/google/protobuf/api_pb.rb

Overview

Api is a light-weight descriptor for an API Interface.

Interfaces are also described as “protocol buffer services” in some contexts, such as by the “service” keyword in a .proto file, but they are different from API Services, which represent a concrete implementation of an interface as opposed to simply a description of methods and bindings. They are also sometimes simply referred to as “APIs” in other contexts, such as the name of this message itself. See cloud.google.com/apis/design/glossary for detailed terminology.