Class: Google::Protobuf::Edition

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Enum
Defined in:
lib/google/protobuf/descriptor_pb.rb

Overview

The full set of known editions.

Constant Summary collapse

EDITION_UNKNOWN =

A placeholder for an unknown edition value.

new("EDITION_UNKNOWN", 0).freeze
EDITION_PROTO2 =

Legacy syntax “editions”. These pre-date editions, but behave much like distinct editions. These can’t be used to specify the edition of proto files, but feature definitions must supply proto2/proto3 defaults for backwards compatibility.

new("EDITION_PROTO2", 998).freeze
EDITION_PROTO3 =
new("EDITION_PROTO3", 999).freeze
EDITION_2023 =

Editions that have been released. The specific values are arbitrary and should not be depended on, but they will always be time-ordered for easy comparison.

new("EDITION_2023", 1_000).freeze
EDITION_2024 =
new("EDITION_2024", 1_001).freeze
EDITION_1_TEST_ONLY =

Placeholder editions for testing feature resolution. These should not be used or relyed on outside of tests.

new("EDITION_1_TEST_ONLY", 1).freeze
EDITION_2_TEST_ONLY =
new("EDITION_2_TEST_ONLY", 2).freeze
EDITION_99997_TEST_ONLY =
new("EDITION_99997_TEST_ONLY", 99_997).freeze
EDITION_99998_TEST_ONLY =
new("EDITION_99998_TEST_ONLY", 99_998).freeze
EDITION_99999_TEST_ONLY =
new("EDITION_99999_TEST_ONLY", 99_999).freeze
EDITION_MAX =

Placeholder for specifying unbounded edition support. This should only ever be used by plugins that can expect to never require any changes to support a new edition.

new("EDITION_MAX", 2_147_483_647).freeze