Class: Google::Protobuf::FieldOptions::OptionRetention

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Enum
Defined in:
lib/google/protobuf/descriptor_pb.rb

Overview

If set to RETENTION_SOURCE, the option will be omitted from the binary. Note: as of January 2023, support for this is in progress and does not yet have an effect (b/264593489).

Constant Summary collapse

RETENTION_UNKNOWN =
new("RETENTION_UNKNOWN", 0).freeze
RETENTION_RUNTIME =
new("RETENTION_RUNTIME", 1).freeze
RETENTION_SOURCE =
new("RETENTION_SOURCE", 2).freeze