Class: Google::Protobuf::GeneratedCodeInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/google/protobuf/descriptor_pb.rb

Overview

Describes the relationship between generated code and its original source file. A GeneratedCodeInfo message is associated with only one generated source file, but may contain references to different source .proto files.

Defined Under Namespace

Classes: Annotation