Class: Google::Protobuf::GeneratedCodeInfo::Annotation::Semantic

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Enum
Defined in:
lib/google/protobuf/descriptor_pb.rb

Overview

Represents the identified object’s effect on the element in the original .proto file.

Constant Summary collapse

NONE =

There is no effect or the effect is indescribable.

new("NONE", 0).freeze
SET =

The element is set or otherwise mutated.

new("SET", 1).freeze
ALIAS =

An alias to the element is returned.

new("ALIAS", 2).freeze