Class: Google::Protobuf::UninterpretedOption

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/google/protobuf/descriptor_pb.rb

Overview

A message representing a option the parser does not recognize. This only appears in options protos created by the compiler::Parser class. DescriptorPool resolves these when building Descriptor objects. Therefore, options protos in descriptor objects (e.g. returned by Descriptor::options(), or produced by Descriptor::CopyTo()) will never have UninterpretedOptions in them.

Defined Under Namespace

Classes: NamePart