Class: Google::Protobuf::Value

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/google/protobuf/struct_pb.rb

Overview

‘Value` represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.

The JSON representation for ‘Value` is JSON value.