Class: Google::Protobuf::FeatureSet
- Inherits:
-
Object
- Object
- Google::Protobuf::FeatureSet
- Extended by:
- Protobug::Message
- Defined in:
- lib/google/protobuf/descriptor_pb.rb
Overview
TODO Enums in C++ gencode (and potentially other languages) are not well scoped. This means that each of the feature enums below can clash with each other. The short names we’ve chosen maximize call-site readability, but leave us very open to this scenario. A future feature will be designed and implemented to handle this, hopefully before we ever hit a conflict here.
Defined Under Namespace
Classes: EnumType, FieldPresence, JsonFormat, MessageEncoding, RepeatedFieldEncoding, Utf8Validation