Class: Google::Protobuf::FeatureSetDefaults
- Inherits:
-
Object
- Object
- Google::Protobuf::FeatureSetDefaults
- Extended by:
- Protobug::Message
- Defined in:
- lib/google/protobuf/descriptor_pb.rb
Overview
A compiled specification for the defaults of a set of features. These messages are generated from FeatureSet extensions and can be used to seed feature resolution. The resolution with this object becomes a simple search for the closest matching edition, followed by proto merges.
Defined Under Namespace
Classes: FeatureSetEditionDefault